/*
	File:		NetworkSetupTest.c

	Contains:	A simple test program for the NetworkSetupHelpers library.

	Written by:	Quinn

	Copyright:	Copyright  1998 by Apple Computer, Inc., all rights reserved.

				You may incorporate this Apple sample source code into your program(s) without
				restriction. This Apple sample source code has been provided "AS IS" and the
				responsibility for its operation is yours. You are not permitted to redistribute
				this Apple sample source code as "Apple sample source code" after having made
				changes. If you're going to re-distribute the source, we require that you make
				it clear in the source that the code was descended from Apple sample source
				code, but that you've made changes.

	Change History (most recent first):

         <6>    10/11/98    Quinn   Convert "MorePrefix.h" to "MoreSetup.h".
         <5>     9/11/98    Quinn   AppleTalk on/off support.
         <4>     9/11/98    Quinn   Add "TCP will dial" code.
         <3>     5/11/98    Quinn   Use MoreAssertQ instead of MoreAssert.
         <2>     5/11/98    Quinn   Fix headers.
         <1>     5/11/98    Quinn   First checked in.
*/

/////////////////////////////////////////////////////////////////
// MoreIsBetter Setup

#include "MoreSetup.h"

/////////////////////////////////////////////////////////////////
// Mac OS Interfaces

#include <Types.h>
#include <Gestalt.h>
#include <NetworkSetupTypes.h>

/////////////////////////////////////////////////////////////////
// Standard C Interfaces

#include <stdio.h>

/////////////////////////////////////////////////////////////////
// MIB Interfaces

#include "NetworkSetupHelpers.h"

/////////////////////////////////////////////////////////////////

enum {
	kOTVersion111 = 0x01118000
};

void main(void) 
{
	OSStatus err;
	UInt32 otVersion;
	NSHConfigurationListHandle configList = nil;
	ItemCount i;
	char commandStr[256];
	OSType protocol;
	char *protocolName;
	const char selectedChars[2] = " *";
	UInt32 willDial;
	Boolean activeAppleTalk;
	
	printf("NetworkSetupTest\n");
	printf("-- A simple test program for the NetworkSetupHelpers library..\n\n");

	err = InitOpenTransport();
	if (err == noErr) {
		err = Gestalt(gestaltOpenTptVersions, (long *) &otVersion);
		if (err != noErr || otVersion < kOTVersion111) {
			printf("This program requires Open Transport 1.1.1 or higher.\n");
			err = -8;
		}

		// Ask the user which protocol they're interested in.
		
		if (err == noErr) {
			printf("a) TCP/IP\n");
			printf("b) AppleTalk\n");
			printf("\n");
			printf("Choose a protocol:\n");
			gets(commandStr);
			switch (commandStr[0]) {
				case 'a':
					protocolName = "TCP/IP";
					protocol = kOTTCPv4NetworkConnection;
					break;
				case 'b':
					protocolName = "AppleTalk";
					protocol = kOTAppleTalkNetworkConnection;
					break;
				default:
					printf("Huh?\n");
					err = userCanceledErr;
					break;
			}
			printf("\n");
		}
		
		// Do some arbitrary protocol-specific queries.
		
		if (err == noErr) {
			if (protocol == kOTTCPv4NetworkConnection) {
				printf("Determining whether TCP/IP will dial...\n\n");
				err = NSHTCPWillDial(&willDial);
				if (err == noErr) {
					switch (willDial) {
						case kNSHTCPDialUnknown:
							printf("  Unknown.\n\n");
							break;
						case kNSHTCPDialTCPDisabled:
							printf("  TCP/IP is disabled.\n\n");
							break;
						case kNSHTCPDialYes:
							printf("  TCP/IP will dial.\n\n");
							break;
						case kNSHTCPDialNo:
							printf("  TCP/IP will not dial.\n\n");
							break;
						default:
							MoreAssertQ(false);
							break;
					}
				}
			} else if (protocol == kOTAppleTalkNetworkConnection) {
				printf("Determining whether AppleTalk is active...\n\n");
				err = NSHIsAppleTalkActive(&activeAppleTalk);
				if (err == noErr) {
					if (activeAppleTalk) {
						printf("  AppleTalk active.\n\n");
					} else {
						printf("  AppleTalk inactive.\n\n");
					}
				}
			} else {
				MoreAssertQ(false);
			}
		}

		// Build and print a configuration list for that protocol.
		
		if (err == noErr) {
			configList = (NSHConfigurationListHandle) NewHandle(0);
			err = MemError();
		}
		
		if (err == noErr) {
			printf("Building configuration list...\n\n");
			MoreAssertQ(configList != nil);			
			err = NSHGetConfigurationList(protocol, configList);
		}
		if (err == noErr) {
			printf("%s Configuration List\n\n", protocolName);
			
			HLock( (Handle) configList );
			for (i = 0; i < NSHCountConfigurationList(configList); i++) {
				printf("%c) %c %#s\n", (char) ('a' + i), selectedChars[(*configList)[i].selected], (*configList)[i].name);
			}
			printf("\n");
		}

		// Ask the user to choose a configuration and switch to that
		// configuration.
		
		if (err == noErr) {
			printf("Choose a configuration:\n");
			gets(commandStr);
			if ( protocol == kOTAppleTalkNetworkConnection && commandStr[0] == '0' ) {
				printf("Deactivating AppleTalk...\n\n");
				err = HSHSetAppleTalkActive(false);
			} else if ( protocol == kOTAppleTalkNetworkConnection && commandStr[0] == '1' ) {
				printf("Activating AppleTalk...\n\n");
				err = HSHSetAppleTalkActive(true);
			} else if ( commandStr[0] >= 'a' && commandStr[0] < ('a' + NSHCountConfigurationList(configList)) ) {
				printf("Selecting configuration...\n\n");
				err = NSHSelectConfiguration(protocol, &(*configList)[commandStr[0] - 'a']);
			} else {
				printf("Huh?\n");
				err = userCanceledErr;
			}
		}
		
		if ( configList != nil ) {
			DisposeHandle( (Handle) configList );
			MoreAssertQ(MemError() == noErr);			
		}
		CloseOpenTransport();
	}
	if (err == noErr) {
		printf("Success.\n");
	} else {
		printf("Failed with error %ld.\n", err);
	}
	printf("Done.  Press command-Q to Quit.\n");
}

